@@ -476,7 +476,7 @@ class App:
     Class variables:
 
         Public:
-            self.kmap = KarnaughMap(raise_error=False, debug=False) - KarnaughMap object to solve the users input
+            self.kmap = KarnaughMap(raise_error=True, debug=False)  - KarnaughMap object to solve the users input
             self.solution = ""                                      - the solution to the map
             self.groups = []                                        - the seperate groups that make up the solution
             self.states = [0, 0, 0]                                 - the settings (Changed by _SettingsApp):
@@ -530,7 +530,7 @@ class App:
             Returns:
                 Nothing (None): Null
         """
-        self.kmap = KarnaughMap(raise_error=False, debug=False)
+        self.kmap = KarnaughMap(raise_error=True, debug=False)
         self.solution = ""
         self.groups = []
         self.states = [0, 0, 0]
@@ -836,11 +836,11 @@ class App:
         # clear error widget
         self._error_message.config(text="")
         self._error_message.pack_forget()
-        self.kmap = KarnaughMap(raise_error=False, debug=False)
+        self.kmap = KarnaughMap(raise_error=True, debug=False)
         if len(self._expression_entry.get()) != 0:
             self.reset_table = self._expression_entry.get()  # store expression for if map is modified
-            self.kmap.create_map(expression=self._expression_entry.get())
             try:
+                self.kmap.create_map(expression=self._expression_entry.get())
                 self.solution = self.kmap.solve_map()  # solve the map
                 # create the solution text as seperate widgets so each group can be highlighted individually
                 for element in self._result_frame.winfo_children():
@@ -866,7 +866,8 @@ class App:
                     self._slider_frame.pack()
                     self._next_group.pack_forget()
                 else:
-                    self._next_group.pack()
+                    if len(self.kmap.groups) > 1:
+                        self._next_group.pack()
                     self._slider_frame.pack_forget()
                 # copy answerto clipboard
                 self.master.clipboard_clear()
@@ -877,7 +878,7 @@ class App:
                                                  self._error_message.pack_forget()))
                 self.rescale()  # draw the map
                 self._job = self.master.after(200, lambda: self.flash_groups(0))  # show the first group
-            except IndexError as e:
+            except (IndexError, ValueError) as e:
                 self._error_message.pack()
                 self._error_message.config(text="Invalid Statement!")
                 print(e)
