@@ -17,7 +17,7 @@ __author__ = "Alexander Bisland"
 __version__ = "1.2.1"
 supported_from = "3.8.1"
 
-import GUI
+from KMap import GUI
 
 
 def cli() -> None:
